==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/EscapeAnalysis.h <==
// public class org.dellroad.jc.cgen.escape.EscapeAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7599210392430771 org_dellroad_jc_cgen_escape_EscapeAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_
#define _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct {
	jboolean	DEBUG;
};
extern _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object *);

// Static methods
extern void _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$method$analyze$41519bd43a800a5d(_jc_env *, struct _jc_soot_toolkits_graph_CompleteUnitGraph$object *, jint);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods	org_dellroad_jc_cgen_escape_EscapeAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs {
    _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs	org_dellroad_jc_cgen_escape_EscapeAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs	org_dellroad_jc_cgen_escape_EscapeAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object {
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_EscapeAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/escape/EscapeAnalysis.h <==
// public class org.dellroad.jc.cgen.escape.EscapeAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7599210392430771 org_dellroad_jc_cgen_escape_EscapeAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_
#define _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_CompleteUnitGraph$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct {
	jboolean	DEBUG;
};
extern _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$fields_struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$method$analyze$41519bd43a800a5d(_jc_env *, struct _jc_soot_toolkits_graph_CompleteUnitGraph$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vmethods	org_dellroad_jc_cgen_escape_EscapeAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs {
    _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_refs	org_dellroad_jc_cgen_escape_EscapeAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$sub_nonrefs	org_dellroad_jc_cgen_escape_EscapeAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$object {
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$vtype _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_EscapeAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_EscapeAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_EscapeAnalysis_H_ */
